@@ -51,6 +51,10 @@
       integer ii1,jj1
 !
       real*8 w(3,3),vo(3,3),elas(21),s(100,100),weight
+!
+      intent(in) w,vo,elas,ii1,jj1,weight
+!
+      intent(inout) s
 !
       s(ii1,jj1)=s(ii1,jj1)+((elas( 1)+elas( 1)*vo(1,1)
      &+elas( 7)*vo(1,2)+elas(11)*vo(1,3)+(elas( 1)+elas( 1)*vo(1,1)+
