@@ -40,6 +40,14 @@
      &  dist,field(nfield,nktet),ratio(20),pneigh(3,20),pnode(3),xi,et,
      &  ze,dist_opt,ratio_opt(20),xp,yp,zp,x(*),y(*),z(*),xo(*),yo(*),
      &  zo(*),value(nfield)
+!
+      intent(in) x,y,z,xo,yo,zo,nx,ny,nz,
+     &         planfa,ifatet,nktet,netet,field,nfield,
+     &         cotet,kontyp,ipkon,kon,iparent,
+     &         xp,yp,zp,iselect,nselect,
+     &         istartset,iendset,ialset,imastset,ielemnr
+!
+      intent(inout) konl,value,nterms,ratio
 !
       tolerance=1.d-6
 !     
