@@ -92,7 +92,7 @@ void cascade(ITG *ipompc, double **coefmpcp, ITG **nodempcp, ITG *nmpc,
     nodempc=*nodempcp;
     coefmpc=*coefmpcp;
     
-    /*           for(i=0;i<*nmpc;i++){
+    /*    for(i=0;i<*nmpc;i++){
 	j=i+1;
 	FORTRAN(writempc,(ipompc,nodempc,coefmpc,labmpc,&j));
 	}*/
@@ -145,8 +145,7 @@ void cascade(ITG *ipompc, double **coefmpcp, ITG **nodempcp, ITG *nmpc,
 	else if((strcmp1(&labmpc[20*i],"RIGID")==0) ||
 	   (strcmp1(&labmpc[20*i],"KNOT")==0) ||
 	   (strcmp1(&labmpc[20*i],"PLANE")==0) ||
-	   (strcmp1(&labmpc[20*i],"STRAIGHT")==0)||
-           (strcmp1(&labmpc[20*i],"ISOCHORIC")==0)) jmpc[i]=1;
+	   (strcmp1(&labmpc[20*i],"STRAIGHT")==0)) jmpc[i]=1;
 
         /* user mpc */
 
