@@ -32,7 +32,7 @@
      &  xstateini,xstate,thicke,
      &  integerglob,doubleglob,tieset,istartset,iendset,
      &  ialset,ntie,nasym,pslavsurf,pmastsurf,mortar,clearini,ielprop,
-     &  prop)
+     &  prop,ne0,kscale)
 !
 !     filling the stiffness matrix in spare matrix format (sm)
 !     asymmetric contributions
@@ -58,7 +58,7 @@
      &  ll,jdof1,jdof2,node1,node2,id,i0,id1,id2,idof1,idof2,nasym,
      &  ntmat_,indexe,nope,norien,iexpl,ncmat_,istep,iinc,mpc2,
      &  nplicon(0:ntmat_,*),nplkcon(0:ntmat_,*),npmat_,ist1,ist2,
-     &  mortar,ielprop(*)
+     &  mortar,ielprop(*),kscale
 !
       real*8 co(3,*),xboun(*),coefmpc(*),xforc(*),xload(2,*),p1(3),
      &  p2(3),ad(*),au(*),bodyf(3),bb(*),xloadold(2,*),value,
@@ -107,9 +107,9 @@
       if((ithermal(1).le.1).or.(ithermal(1).eq.3)) then
 !
 !     mechanical analysis: asymmetric contributions
+!     only contact friction
 !
-      ne0=0
-      do i=1,ne
+      do i=ne0+1,ne
 !
         if(ipkon(i).lt.0) cycle
         if(lakon(i)(1:2).ne.'ES') cycle
@@ -137,7 +137,7 @@
      &          springarea,nstate_,xstateini,xstate,ne0,ipkon,thicke,
      &          integerglob,
      &          doubleglob,tieset,istartset,iendset,ialset,ntie,nasym,
-     &          pslavsurf,pmastsurf,mortar,clearini,ielprop,prop)
+     &          pslavsurf,pmastsurf,mortar,clearini,ielprop,prop,kscale)
 !
         do jj=1,3*nope
 !
