@@ -30,8 +30,8 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	      ITG *jq, ITG **mast1p, ITG **irowp, ITG *isolver, ITG *neq,
 	      ITG *ikmpc, ITG *ilmpc,ITG *ipointer, ITG *nzs, 
               ITG *nmethod,ITG *ithermal, ITG *ikboun, ITG *ilboun, 
-              ITG *iperturb, ITG *mi,ITG *mortar,char *typeboun,
-              char *labmpc){
+              ITG *iperturb, ITG *mi, ITG *mortar, char *typeboun,
+              char *labmpc, ITG *iit, ITG *icascade){
 
   /* determines the structure of the thermo-mechanical matrices;
      (i.e. the location of the nonzeros */
@@ -41,7 +41,8 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
   ITG i,j,k,l,jj,ll,id,index,jdof1,jdof2,idof1,idof2,mpc1,mpc2,id1,id2,
     ist1,ist2,node1,node2,isubtract,nmast,ifree,istart,istartold,
     index1,index2,m,node,nzs_,ist,kflag,indexe,nope,isize,*mast1=NULL,
-      *irow=NULL,icolumn,nmastboun,mt=mi[1]+1,jmax;
+    *irow=NULL,icolumn,nmastboun,mt=mi[1]+1,jmax,*next=NULL,nopeold,
+    indexeold,identical;
 
   /* the indices in the comments follow FORTRAN convention, i.e. the
      fields start with 1 */
@@ -49,167 +50,184 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
   mast1=*mast1p;
   irow=*irowp;
 
-  kflag=2;
-  nzs_=nzs[1];
+  kflag=1;
 
-  /* initialisation of nactmpc */
+  /* determining nactdof (only at start of step or if MPC's
+     changed */
 
-  for(i=0;i<mt**nk;++i){nactdof[i]=0;}
+  if((*iit<0)||(*icascade!=0)){
 
-  /* determining the mechanical active degrees of freedom due to elements */
-  if((*ithermal<2)||(*ithermal>=3)){
-      for(i=0;i<*ne;++i){
-	  
-	  if(ipkon[i]<0) continue;
-	  if(strcmp1(&lakon[8*i],"F")==0)continue;
-	  indexe=ipkon[i];
+      /* initialisation of nactdof */
+      
+      for(i=0;i<mt**nk;++i){nactdof[i]=0;}
+      
+      /* determining the mechanical active degrees of freedom due to elements */
+      if((*ithermal<2)||(*ithermal>=3)){
+	  for(i=0;i<*ne;++i){
+	      
+	      if(ipkon[i]<0) continue;
+	      if(strcmp1(&lakon[8*i],"F")==0)continue;
+	      indexe=ipkon[i];
 /* Bernhardi start */
-          if (strcmp1(&lakon[8*i+3],"8I")==0)nope=11;
-	  else if(strcmp1(&lakon[8*i+3],"20")==0)nope=20;
+	      if (strcmp1(&lakon[8*i+3],"8I")==0)nope=11;
+	      else if(strcmp1(&lakon[8*i+3],"20")==0)nope=20;
 /* Bernhardi end */
-	  else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
-	  else if (strcmp1(&lakon[8*i+3],"8")==0)nope=8;
-	  else if (strcmp1(&lakon[8*i+3],"10")==0)nope=10;
-	  else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
-	  else if ((strcmp1(&lakon[8*i+3],"4")==0)||
-                   (strcmp1(&lakon[8*i+2],"4")==0)) nope=4;
-	  else if (strcmp1(&lakon[8*i+3],"15")==0)nope=15;
-	  else if (strcmp1(&lakon[8*i+3],"6")==0)nope=6;
-	  else if (strcmp1(&lakon[8*i],"E")==0){
-	      if((strcmp1(&lakon[8*i+6],"C")==0)&&(*mortar==1)){
-		  nope=kon[ipkon[i]-1];
-	      }else{
-		  lakonl[0]=lakon[8*i+7];
-		  nope=atoi(lakonl)+1;
-	      }
-	  }else continue;
-	  
-          /* displacement degrees of freedom */
-
-	  for(j=0;j<nope;++j){
-	      node=kon[indexe+j]-1;
-	      for(k=1;k<4;++k){
-		  nactdof[mt*node+k]=1;
+//	      else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
+	      else if (strcmp1(&lakon[8*i+3],"8")==0)nope=8;
+	      else if (strcmp1(&lakon[8*i+3],"10")==0)nope=10;
+//	      else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
+	      else if ((strcmp1(&lakon[8*i+3],"4")==0)||
+		       (strcmp1(&lakon[8*i+2],"4")==0)) nope=4;
+	      else if (strcmp1(&lakon[8*i+3],"15")==0)nope=15;
+	      else if (strcmp1(&lakon[8*i+3],"6")==0)nope=6;
+	      else if (strcmp1(&lakon[8*i],"E")==0){
+		  if((strcmp1(&lakon[8*i+6],"C")==0)&&(*mortar==1)){
+//		  nope=kon[ipkon[i]-1];
+		      continue;
+		  }else{
+		      lakonl[0]=lakon[8*i+7];
+		      nope=atoi(lakonl)+1;
+		  }
+	      }else continue;
+	      
+	      /* displacement degrees of freedom */
+	      
+	      for(j=0;j<nope;++j){
+		  node=kon[indexe+j]-1;
+		  for(k=1;k<4;++k){
+		      nactdof[mt*node+k]=1;
+		  }
 	      }
 	  }
       }
-  }
-
-  /* determining the thermal active degrees of freedom due to elements */
-
-  if(*ithermal>1){
-      for(i=0;i<*ne;++i){
-	  
-	  if(ipkon[i]<0) continue;
-	  if(strcmp1(&lakon[8*i],"F")==0)continue;
-	  indexe=ipkon[i];
-	  if(strcmp1(&lakon[8*i+3],"20")==0)nope=20;
-	  else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
-	  else if (strcmp1(&lakon[8*i+3],"8")==0)nope=8;
-	  else if (strcmp1(&lakon[8*i+3],"10")==0)nope=10;
-	  else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
-	  else if (strcmp1(&lakon[8*i+3],"4")==0)nope=4;
-	  else if (strcmp1(&lakon[8*i+3],"15")==0)nope=15;
-	  else if (strcmp1(&lakon[8*i+3],"6")==0)nope=6;
-	  else if (strcmp1(&lakon[8*i],"E")==0){
-	      if((strcmp1(&lakon[8*i+6],"C")==0)&&(*mortar==1)){
-		  nope=kon[ipkon[i]-1];
-	      }else{
-		  lakonl[0]=lakon[8*i+7];
-		  nope=atoi(lakonl)+1;
-	      }
-	  }else if (strcmp1(&lakon[8*i],"D ")==0){
-
-	      /* check for entry or exit element */
+      
+      /* determining the thermal active degrees of freedom due to elements */
+      
+      if(*ithermal>1){
+	  for(i=0;i<*ne;++i){
 	      
-	      if((kon[indexe]==0)||(kon[indexe+2]==0)) continue;
+	      if(ipkon[i]<0) continue;
+	      if(strcmp1(&lakon[8*i],"F")==0)continue;
+	      indexe=ipkon[i];
+	      if(strcmp1(&lakon[8*i+3],"20")==0)nope=20;
+//	      else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
+	      else if (strcmp1(&lakon[8*i+3],"8")==0)nope=8;
+	      else if (strcmp1(&lakon[8*i+3],"10")==0)nope=10;
+//	      else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
+	      else if (strcmp1(&lakon[8*i+3],"4")==0)nope=4;
+	      else if (strcmp1(&lakon[8*i+3],"15")==0)nope=15;
+	      else if (strcmp1(&lakon[8*i+3],"6")==0)nope=6;
+	      else if (strcmp1(&lakon[8*i],"E")==0){
+		  if((strcmp1(&lakon[8*i+6],"C")==0)&&(*mortar==1)){
+//		  nope=kon[ipkon[i]-1];
+		      continue;
+		  }else{
+		      lakonl[0]=lakon[8*i+7];
+		      nope=atoi(lakonl)+1;
+		  }
+	      }else if (strcmp1(&lakon[8*i],"D ")==0){
+		  
+		  /* check for entry or exit element */
+		  
+		  if((kon[indexe]==0)||(kon[indexe+2]==0)) continue;
+		  
+		  /* generic network element */
+		  
+		  for(j=0;j<3;j=j+2){
+		      node=kon[indexe+j]-1;
+		      nactdof[mt*node]=1;
+		  }
+		  continue;}
+	      else continue;
 	      
-	      /* generic network element */
-	      
-	      for(j=0;j<3;j=j+2){
+	      for(j=0;j<nope;++j){
 		  node=kon[indexe+j]-1;
 		  nactdof[mt*node]=1;
 	      }
-	      continue;}
-	  else continue;
-	  
-	  for(j=0;j<nope;++j){
-	      node=kon[indexe+j]-1;
-	      nactdof[mt*node]=1;
 	  }
       }
-  }
-
-  /* determining the active degrees of freedom due to mpc's */
-
-  for(i=0;i<*nmpc;++i){
-      if (strcmp1(&labmpc[20*i],"FLUID")==0) continue;
-      index=ipompc[i]-1;
-      do{
-	  if(nodempc[3*index+1]<4){
-	      nactdof[mt*(nodempc[3*index]-1)+nodempc[3*index+1]]=1;
+      
+      /* determining the active degrees of freedom due to mpc's */
+      
+      for(i=0;i<*nmpc;++i){
+	  if (strcmp1(&labmpc[20*i],"FLUID")==0) continue;
+	  index=ipompc[i]-1;
+	  do{
+	      if(nodempc[3*index+1]<4){
+		  nactdof[mt*(nodempc[3*index]-1)+nodempc[3*index+1]]=1;
+	      }
+	      index=nodempc[3*index+2];
+	      if(index==0) break;
+	      index--;
+	  }while(1);
+      }
+      
+      /* subtracting the SPC and MPC nodes */
+      
+      for(i=0;i<*nboun;++i){
+	  if(ndirboun[i]>mi[1]) continue;
+	  if (strcmp1(&typeboun[i],"F")==0) continue;
+	  nactdof[mt*(nodeboun[i]-1)+ndirboun[i]]=0;
+      }
+      
+      for(i=0;i<*nmpc;++i){
+	  if (strcmp1(&labmpc[20*i],"FLUID")==0) continue;
+	  index=ipompc[i]-1;
+	  if(nodempc[3*index+1]>mi[1]) continue;
+	  nactdof[mt*(nodempc[3*index]-1)+nodempc[3*index+1]]=0;
+      }
+      
+      /* numbering the active degrees of freedom */
+      
+      neq[0]=0;
+      for(i=0;i<*nk;++i){
+	  for(j=1;j<mt;++j){
+	      if(nactdof[mt*i+j]!=0){
+		  if((*ithermal<2)||(*ithermal>=3)){
+		      ++neq[0];
+		      nactdof[mt*i+j]=neq[0];
+		  }
+		  else{
+		      nactdof[mt*i+j]=0;
+		  }
+	      }
 	  }
-	  index=nodempc[3*index+2];
-	  if(index==0) break;
-	  index--;
-      }while(1);
+      }
+      neq[1]=neq[0];
+      for(i=0;i<*nk;++i){
+	  if(nactdof[mt*i]!=0){
+	      if(*ithermal>1){
+		  ++neq[1];
+		  nactdof[mt*i]=neq[1];
+	      }
+	      else{
+		  nactdof[mt*i]=0;
+	      }
+	  }
+      }
+      if((*nmethod==2)||((*nmethod==4)&&(*iperturb<=1))||((*nmethod>=5)&&(*nmethod<=7))){
+	  neq[2]=neq[1]+*nboun;
+      }
+      else{neq[2]=neq[1];}
   }
-	   
-  /* subtracting the SPC and MPC nodes */
-
-  for(i=0;i<*nboun;++i){
-      if(ndirboun[i]>mi[1]) continue;
-      if (strcmp1(&typeboun[i],"F")==0) continue;
-      nactdof[mt*(nodeboun[i]-1)+ndirboun[i]]=0;
-  }
-
-  for(i=0;i<*nmpc;++i){
-      if (strcmp1(&labmpc[20*i],"FLUID")==0) continue;
-      index=ipompc[i]-1;
-      if(nodempc[3*index+1]>mi[1]) continue;
-      nactdof[mt*(nodempc[3*index]-1)+nodempc[3*index+1]]=0;
-  }
- 
-  /* numbering the active degrees of freedom */
-  
-  neq[0]=0;
-  for(i=0;i<*nk;++i){
-    for(j=1;j<mt;++j){
-	if(nactdof[mt*i+j]!=0){
-        if((*ithermal<2)||(*ithermal>=3)){
-          ++neq[0];
-          nactdof[mt*i+j]=neq[0];
-        }
-        else{
-	    nactdof[mt*i+j]=0;
-        }
-      }
-    }
-  }
-  neq[1]=neq[0];
-  for(i=0;i<*nk;++i){
-      if(nactdof[mt*i]!=0){
-      if(*ithermal>1){
-        ++neq[1];
-        nactdof[mt*i]=neq[1];
-      }
-      else{
-	  nactdof[mt*i]=0;
-      }
-    }
-  }
-  if((*nmethod==2)||((*nmethod==4)&&(*iperturb<=1))||((*nmethod>=5)&&(*nmethod<=7))){
-      neq[2]=neq[1]+*nboun;
-  }
-  else{neq[2]=neq[1];}
   
+  /* determining the subdiagonal nonzeros in the stiffness/mass matrix */
+
   ifree=0;
+  nzs_=nzs[1];
+  NNEW(next,ITG,nzs_);
 
     /* determining the position of each nonzero matrix element in
-       the SUPERdiagonal matrix */
+       the SUBdiagonal matrix (excluding diagonal): x-elements on
+       the left of the vertical line */
+
+//               |x x x
+//        x      |x x x
+//        x x    |x x x
+//        x x x  |x x x
 
     /*   mast1(ipointer(i)) = first nonzero row in column i
-	 irow(ipointer(i))  points to further nonzero elements in 
+	 next(ipointer(i))  points to further nonzero elements in 
                              column i */
       
     for(i=0;i<4**nk;++i){ipointer[i]=0;}
@@ -227,16 +245,29 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
       if (strcmp1(&lakon[8*i+3],"8I")==0)nope=11;
       else if(strcmp1(&lakon[8*i+3],"20")==0)nope=20;
 /* Bernhardi end */
-      else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
+//      else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
       else if (strcmp1(&lakon[8*i+3],"8")==0)nope=8;
       else if (strcmp1(&lakon[8*i+3],"10")==0)nope=10;
-      else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
+//      else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
       else if (strcmp1(&lakon[8*i+3],"4")==0)nope=4;
       else if (strcmp1(&lakon[8*i+3],"15")==0)nope=15;
       else if (strcmp1(&lakon[8*i+3],"6")==0)nope=6;
       else if (strcmp1(&lakon[8*i],"E")==0){
 	  if((strcmp1(&lakon[8*i+6],"C")==0)&&(*mortar==1)){
-	      nope=kon[ipkon[i]-1];
+//	      nope=kon[ipkon[i]-1];
+	      nope=kon[indexe-1];
+	      if(nope==nopeold){
+		  identical=1;
+		  for(j=0;j<nope;j++){
+		      if(kon[indexe+j]!=kon[indexeold+j]){
+			  identical=0;
+			  break;
+		      }
+		  }
+		  if(identical==1)continue;
+	      }
+	      nopeold=nope;
+	      indexeold=indexe;
 	  }else{
 	      lakonl[0]=lakon[8*i+7];
 	      nope=atoi(lakonl)+1;
@@ -262,7 +293,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	  /* check whether one of the DOF belongs to a SPC or MPC */
 	  
 	  if((jdof1!=0)&&(jdof2!=0)){
-	    insert(ipointer,&mast1,&irow,&jdof1,&jdof2,&ifree,&nzs_);
+	    insert(ipointer,&mast1,&next,&jdof1,&jdof2,&ifree,&nzs_);
 	  }
 	  else if((jdof1!=0)||(jdof2!=0)){
 	    
@@ -290,7 +321,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		while(1){
 		    idof2=nactdof[mt*(nodempc[3*index-3]-1)+nodempc[3*index-2]];
 		  if(idof2!=0){
-		    insert(ipointer,&mast1,&irow,&idof1,&idof2,&ifree,&nzs_);
+		    insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);
 		  }
 		  index=nodempc[3*index-1];
 		  if(index==0) break;
@@ -300,12 +331,18 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	    }
 
             /* boundary stiffness coefficients (for frequency
-               and modal dynamic calculations) */
+               and modal dynamic calculations) : x-elements
+               on the right of the vertical line */
+
+//               |x x x
+//        x      |x x x
+//        x x    |x x x
+//        x x x  |x x x
 
 	    if((*nmethod==2)||((*nmethod==4)&&(*iperturb<=1))||((*nmethod>=5)&&(*nmethod<=7))){
 		FORTRAN(nident,(ikboun,&idof2,nboun,&id)); 
 		icolumn=neq[1]+ilboun[id-1];
-    	 	insert(ipointer,&mast1,&irow,&idof1,&icolumn,&ifree,&nzs_);
+    	 	insertfreq(ipointer,&mast1,&next,&idof1,&icolumn,&ifree,&nzs_);
 	    }
 	  }
 	  
@@ -336,7 +373,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		  while(1){
 		      idof2=nactdof[mt*(nodempc[3*index2-3]-1)+nodempc[3*index2-2]];
 		    if((idof1!=0)&&(idof2!=0)){
-		      insert(ipointer,&mast1,&irow,&idof1,&idof2,&ifree,&nzs_);}
+		      insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);}
 		    index2=nodempc[3*index2-1];
 		    if(index2==0) break;
 		  }
@@ -364,7 +401,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		  while(1){
 		      idof2=nactdof[mt*(nodempc[3*index2-3]-1)+nodempc[3*index2-2]];
 		    if((idof1!=0)&&(idof2!=0)){
-		      insert(ipointer,&mast1,&irow,&idof1,&idof2,&ifree,&nzs_);}
+		      insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);}
 		    index2=nodempc[3*index2-1];
 		    if(index2==0) break;
 		  }
@@ -390,16 +427,29 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
       if(strcmp1(&lakon[8*i],"F")==0)continue;
       indexe=ipkon[i];
       if(strcmp1(&lakon[8*i+3],"20")==0)nope=20;
-      else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
+//      else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
       else if (strcmp1(&lakon[8*i+3],"8")==0)nope=8;
       else if (strcmp1(&lakon[8*i+3],"10")==0)nope=10;
-      else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
+//      else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
       else if (strcmp1(&lakon[8*i+3],"4")==0)nope=4;
       else if (strcmp1(&lakon[8*i+3],"15")==0)nope=15;
       else if (strcmp1(&lakon[8*i+3],"6")==0)nope=6;
       else if (strcmp1(&lakon[8*i],"E")==0){
 	  if((strcmp1(&lakon[8*i+6],"C")==0)&&(*mortar==1)){
-	      nope=kon[ipkon[i]-1];
+//	      nope=kon[ipkon[i]-1];
+	      nope=kon[indexe-1];
+	      if(nope==nopeold){
+		  identical=1;
+		  for(j=0;j<nope;j++){
+		      if(kon[indexe+j]!=kon[indexeold+j]){
+			  identical=0;
+			  break;
+		      }
+		  }
+		  if(identical==1)continue;
+	      }
+	      nopeold=nope;
+	      indexeold=indexe;
 	  }else{
 	      lakonl[0]=lakon[8*i+7];
 	      nope=atoi(lakonl)+1;
@@ -429,7 +479,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	  /* check whether one of the DOF belongs to a SPC or MPC */
 	  
 	  if((jdof1!=0)&&(jdof2!=0)){
-	    insert(ipointer,&mast1,&irow,&jdof1,&jdof2,&ifree,&nzs_);
+	    insert(ipointer,&mast1,&next,&jdof1,&jdof2,&ifree,&nzs_);
 	  }
 	  else if((jdof1!=0)||(jdof2!=0)){
 	    
@@ -457,7 +507,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		while(1){
 		    idof2=nactdof[mt*(nodempc[3*index-3]-1)+nodempc[3*index-2]];
 		  if(idof2!=0){
-		    insert(ipointer,&mast1,&irow,&idof1,&idof2,&ifree,&nzs_);
+		    insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);
 		  }
 		  index=nodempc[3*index-1];
 		  if(index==0) break;
@@ -472,7 +522,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	    if((*nmethod==2)||((*nmethod==4)&&(*iperturb<=1))||((*nmethod>=5)&&(*nmethod<=7))){
 		FORTRAN(nident,(ikboun,&idof2,nboun,&id));
 		icolumn=neq[1]+ilboun[id-1];
-		insert(ipointer,&mast1,&irow,&idof1,&icolumn,&ifree,&nzs_);
+		insertfreq(ipointer,&mast1,&next,&idof1,&icolumn,&ifree,&nzs_);
 	    }
 
 	  }
@@ -504,7 +554,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		  while(1){
 		      idof2=nactdof[mt*(nodempc[3*index2-3]-1)+nodempc[3*index2-2]];
 		    if((idof1!=0)&&(idof2!=0)){
-		      insert(ipointer,&mast1,&irow,&idof1,&idof2,&ifree,&nzs_);}
+		      insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);}
 		    index2=nodempc[3*index2-1];
 		    if(index2==0) break;
 		  }
@@ -532,7 +582,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		  while(1){
 		      idof2=nactdof[mt*(nodempc[3*index2-3]-1)+nodempc[3*index2-2]];
 		    if((idof1!=0)&&(idof2!=0)){
-		      insert(ipointer,&mast1,&irow,&idof1,&idof2,&ifree,&nzs_);}
+		      insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);}
 		    index2=nodempc[3*index2-1];
 		    if(index2==0) break;
 		  }
@@ -548,53 +598,29 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 
     }
 
-    /*   storing the nonzero nodes in the SUPERdiagonal columns:
-	 mast1 contains the row numbers,
-	 irow the column numbers  */
-    
-    for(i=0;i<neq[2];++i){
-	if(ipointer[i]==0){
-	    if(i>=neq[1]) continue;
-	    node1=0;
-	    for(j=0;j<*nk;j++){
-		for(k=0;k<4;++k){
-		    if(nactdof[mt*j+k]==i+1){
-			node1=j+1;
-			idof1=k;
-			break;
-		    }
-		}
-		if(node1!=0) break;
-	    }
-	    printf("*ERROR in mastruct: zero column\n");
-	    printf("       node=%" ITGFORMAT ",DOF=%" ITGFORMAT "\n",node1,idof1);
-	    FORTRAN(stop,());
-	}
-	istart=ipointer[i];
-	while(1){
-	    istartold=istart;
-	    istart=irow[istart-1];
-	    irow[istartold-1]=i+1;
-	    if(istart==0) break;
-	}
-    }
-
     if(neq[1]==0){
-      printf("\n*WARNING: no degrees of freedom in the model\n\n");
+      printf("\n *WARNING: no degrees of freedom in the model\n\n");
     }
 
-    nmast=ifree;
+    /*   determination of the following fields:       
 
-    /* for frequency calculations and modal dynamic calculations: 
-       sorting column after column;
-       determining the end of the classical stiffness matrix
-       in fields irow and mast1 */
+       - irow: row numbers, column per column
+       - icol(i)=# SUBdiagonal nonzero's in column i
+       - jq(i)= location in field irow of the first SUBdiagonal
+         nonzero in column i  */
 
-    if((*nmethod==2)||((*nmethod==4)&&(*iperturb<=1))||((*nmethod>=5)&&(*nmethod<=7))){
-	FORTRAN(isortii,(irow,mast1,&nmast,&kflag));
-	nmastboun=nmast;
-	FORTRAN(nident,(irow,&neq[1],&nmast,&id));
-	if((id>0)&&(irow[id-1]==neq[1])) nmast=id;
+    RENEW(irow,ITG,ifree);
+    nmast=0;
+    jq[0]=1;
+    for(i=0;i<neq[1];i++){
+	index=ipointer[i];
+	do{
+	    if(index==0) break;
+	    irow[nmast++]=mast1[index-1];
+	    index=next[index-1];
+	}while(1);
+	jq[i+1]=nmast+1;
+	icol[i]=jq[i+1]-jq[i];
     }
 
     /* summary */
@@ -602,83 +628,42 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
     printf(" number of equations\n");
     printf(" %" ITGFORMAT "\n",neq[1]);
     printf(" number of nonzero lower triangular matrix elements\n");
-    printf(" %" ITGFORMAT "\n",nmast-neq[1]);
+    printf(" %" ITGFORMAT "\n",nmast);
     printf("\n");
 
-    /* switching from a SUPERdiagonal inventory to a SUBdiagonal one:
-       since the nonzeros are located in symmetric positions mast1
-       can be considered to contain the column numbers and irow the
-       row numbers; after sorting mast1 the following results:
-
-       - irow contains the row numbers of the SUBdiagonal
-         nonzero's, column per column
-       - mast1 contains the column numbers
-
-       Furthermore, the following fields are determined:       
-
-       - icol(i)=# SUBdiagonal nonzero's in column i
-       - jq(i)= location in field irow of the first SUBdiagonal
-         nonzero in column i  */
-
-    /* ordering the column numbers in mast1 */
-
-    FORTRAN(isortii,(mast1,irow,&nmast,&kflag));
-    
-    /* filtering out the diagonal elements and generating icol and jq */
-
-    isubtract=0;
-    for(i=0;i<neq[1];++i){icol[i]=0;}
-    k=0;
-    for(i=0;i<nmast;++i){
-      if(mast1[i]==irow[i]){++isubtract;}
-      else{
-	mast1[i-isubtract]=mast1[i];
-	irow[i-isubtract]=irow[i];
-	if(k!=mast1[i]){
-	  for(l=k;l<mast1[i];++l){jq[l]=i+1-isubtract;}
-	  k=mast1[i];
-	}
-	++icol[k-1];
-      }
-    }
-    nmast=nmast-isubtract;
-    for(l=k;l<neq[1]+1;++l){jq[l]=nmast+1;}
-
     /* sorting the row numbers within each column */
 
     for(i=0;i<neq[1];++i){
-      if(jq[i+1]-jq[i]>0){
-	isize=jq[i+1]-jq[i];
-	FORTRAN(isortii,(&irow[jq[i]-1],&mast1[jq[i]-1],&isize,&kflag));
-      }
+	if(jq[i+1]-jq[i]>0){
+	    isize=jq[i+1]-jq[i];
+	    FORTRAN(isortii,(&irow[jq[i]-1],&mast1[jq[i]-1],&isize,&kflag));
+	}
     }
 
     if(neq[0]==0){nzs[0]=0;}
     else{nzs[0]=jq[neq[0]]-1;}
     nzs[1]=jq[neq[1]]-1;
 
-    /* determining jq for the boundary stiffness matrix (only
+    /* determining irow, jq and icol for the boundary stiffness matrix (only
        for frequency and modal dynamic calculations */
 
     if((*nmethod==2)||((*nmethod==4)&&(*iperturb<=1))||((*nmethod>=5)&&(*nmethod<=7))){
-	for(i=neq[1];i<neq[2];++i){icol[i]=0;}
-	for(i=nmast+isubtract;i<nmastboun;++i){
-	    
-	    /* irow contains the columns, mast1 the rows, so switch! */
-	    
-	    irow[i-isubtract]=mast1[i];
-	    mast1[i-isubtract]=irow[i];
-	    
-            /* now irow contains the rows (up to index i-isubtract) */
 
-	    if(k!=irow[i]){
-		for(l=k;l<irow[i];++l){jq[l]=i+1-isubtract;}
-		k=irow[i];
-	    }
-	    ++icol[k-1];
+	nmastboun=nmast;
+	for(i=neq[1];i<neq[2];i++){
+	    index=ipointer[i];
+	    do{
+		if(index==0) break;
+		irow[nmastboun++]=mast1[index-1];
+//		if(i==720) printf("mastruct i=%d,index=%d,idof1=%d\n",i,index,mast1[index-1]);
+		index=next[index-1];
+	    }while(1);
+	    jq[i+1]=nmastboun+1;
+	    icol[i]=jq[i+1]-jq[i];
 	}
-	nmastboun-=isubtract;
-	for(l=k;l<neq[2]+1;++l){jq[l]=nmastboun+1;}
+
+	/* sorting the row numbers within each column */
+
 	for(i=neq[1];i<neq[2];++i){
 	    if(jq[i+1]-jq[i]>0){
 		isize=jq[i+1]-jq[i];
@@ -689,13 +674,15 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
     }
     else{nzs[2]=nzs[1];}
 
-/*  for(i=nzs[1];i<nzs[2];i++){
-      printf("i=%" ITGFORMAT ",irow[i]=%" ITGFORMAT ",icolumn[i]=%" ITGFORMAT "\n",i+1,irow[i],mast1[i]);
+    /* for(i=0;i<nzs[2];i++){
+      printf("i=%" ITGFORMAT ",irow[i]=%" ITGFORMAT  "\n",i+1,irow[i]);
   }
-  for(i=neq[1];i<neq[2]+1;i++){
+  for(i=0;i<neq[2]+1;i++){
       printf("i=%" ITGFORMAT ",jq[i]=%" ITGFORMAT "\n",i+1,jq[i]);
       }*/
 
+  SFREE(next);
+
   *mast1p=mast1;
   *irowp=irow;
 
