@@ -28,6 +28,7 @@
 !
       implicit none
 !
+      character*80 version
       character*81 set(*)
       character*132 fnrstrt,jobnamec(*)
 !
@@ -41,6 +42,9 @@
 !
       if(icntrl.eq.0) then
 !
+!        this branch is called from readinput.c
+!        its purpose is to read the value of nset
+!
 !        determining the name of the restart file
 !
          ipos=index(jobnamec(1),char(0))
@@ -54,6 +58,12 @@
 !
          open(15,file=fnrstrt,ACCESS='SEQUENTIAL',FORM='UNFORMATTED',
      &      err=15)
+!
+         read(15) version
+         write(*,*)
+         write(*,*) '*INFO: restart file ',fnrstrt
+         write(*,*) '       has been opened for reading.'
+         write(*,*) '       it was created with CalculiX ',version
 !
          do
 !
@@ -67,6 +77,7 @@
                   close(15)
                   open(15,file=fnrstrt,ACCESS='SEQUENTIAL',
      &                 FORM='UNFORMATTED',err=15)
+                  read(15) version
                   read(15,iostat=istat)istep
                else
                   write(*,*) '*ERROR in restartshort: requested step'
@@ -190,6 +201,8 @@
 !
       open(15,file=fnrstrt,ACCESS='SEQUENTIAL',FORM='UNFORMATTED',
      &   err=15)
+!
+      read(15) version
 !
       do
 !
@@ -203,6 +216,7 @@
                close(15)
                open(15,file=fnrstrt,ACCESS='SEQUENTIAL',
      &              FORM='UNFORMATTED',err=15)
+               read(15) version
                read(15,iostat=istat)istep
             else
                write(*,*) '*ERROR in restartshort: requested step'
